# # 人教版小学英语单词表'),
# ('# 三年级上册词汇'),
# ('# 人教版小学英语三年级上册单词表（三会）Unit 1'),
cn_ps_e_words = \
    [
        # 3.1
        [
            [
                # Unit 1
                ('pen', '钢笔'), ('pencil', '铅笔'), ('pencil-case', '铅笔盒'),
                ('ruler', '尺子'), ('eraser', '橡皮'), ('crayon', '蜡笔'),
                ('book', '书'), ('bag', '书包'), ('sharpener', '卷笔刀'),
                ('school', '学校'),
            ],
            [
                # Unit 2
                ('head', '头'), ('face', '脸'), ('nose', '鼻子'),
                ('mouth', '嘴'), ('eye', '眼睛'), ('ear', '耳朵'),
                ('arm', '胳膊'), ('finger', '手指'), ('leg', '腿'),
                ('foot', '脚'), ('body', '身体'),
            ],
            [
                # Unit 3
                ('red', '红色'), ('yellow', '黄色'), ('green', '绿色'),
                ('blue', '蓝色'), ('purple', '紫色'), ('white', '白色'),
                ('black', '黑色'), ('orange', '橙色'), ('pink', '粉色'),
                ('brown', '棕色'),
            ],
            [
                # Unit 4
                ('cat', '猫'), ('dog', '狗'), ('monkey', '猴子'),
                ('panda', '熊猫'),
                ('rabbit', '兔子'), ('duck', '鸭子'), ('pig', '猪'),
                ('bird', '鸟'),
                ('bear', '熊'), ('elephant', '大象'), ('mouse', '老鼠'),
                ('squirrel', '松鼠'),
            ],
            [
                # Unit 5
                ('cake', '蛋糕'), ('bread', '面包'), ('hot dog', '热狗'),
                ('hamburger', '汉堡包'), ('chicken', '鸡肉'),
                ('French fries', '榨薯条'),
                ('Coke', '可乐'), ('juice', '果汁'), ('milk', '牛奶'),
                ('water', '水'),
                ('tea', '茶'), ('coffee', '咖啡'),
            ],
            [
                # Unit 6
                ('one', '一'), ('two', '二'), ('three', '三'), ('four', '四'),
                ('five', '五'), ('six', '六'), ('seven', '七'), ('eight', '八'),
                ('nine', '九'), ('ten', '十'), ('doll', '玩具娃娃'),
                ('boat', '小船'),
                ('ball', '球'), ('kite', '风筝'), ('balloon', '气球'),
                ('car', '小汽车'),
                ('plane', '飞机'),
            ],
        ],
        # 3.2
        [
            [
                # Unit 1
                ('boy', '男孩'), ('girl', '女孩'), ('teacher', '教师'),
                ('student', '学生'), ('this', '这个'), ('my', '我的'),
                ('friend', '朋友'), ('I\'m', '我是'), ('I am', '我是'),
                ('nice', '好的,愉快的'), ('good morning', '早上好'),
                ('good afternoon', '下午好'), ('meet', '遇见；碰见'),
                ('goodbye', '再见'), ('too', '也；太'),
            ],
            [
                # Unit 2
                ('father', '爸爸'), ('dad', '爸爸(口语)'),
                ('mother', '母亲；妈妈'),
                ('mom', '妈妈口语'), ('man', '男人'), ('woman', '女人'),
                ('grandmother', '外祖母'), ('grandma', '[口语]外祖母'),
                ('grandfather', '(外)祖父'), ('grandpa', '[口语](外)祖父'),
                ('sister', '姐妹'), ('brother', '兄妹'), ('let\'s', '让我们'),
                ('let us', '让我们'), ('great', '太好了'),
                ('really', '真地；确切地'),
                ('and', '与；并且'),
            ],
            [
                # Unit 3
                ('eleven', '十一'), ('twelve', '十二'), ('thirteen', '十三'),
                ('fourteen', '十四'), ('fifteen', '十五'), ('sixteen', '十六'),
                ('seventeen', '十七 eighteen', '十八'), ('nineteen', '十九'),
                ('twenty', '二十'), ('how many', '多少'), ('can', '能够；可以'),
                ('look at', '瞧；瞧'),
            ],
            [
                # Unit 4'),
                ('peach', '桃'), ('pear', '梨'), ('orange', '橙子'),
                ('watermelon', '西瓜'), ('apple', '苹果'), ('banana', '香蕉'),
                ('strawberry', '草莓'), ('grape', '葡萄'), ('like', '喜欢'),
                ('some', '一些；某些'), ('thanks', '多谢'),
            ],
            [
                # Unit 5
                ('bus', '公共汽车'), ('bike', '自行车'), ('taxi', '出租车'),
                ('jeep', '吉普车'), ('desk', '课桌'), ('chair', '椅子'),
                ('Walkman', '随身听'), ('lamp', '台灯'), ('your', '您的；您们的'),
                ('zoo', '动物园'),
            ],
            [
                # Unit 6
                ('small', '小的'), ('big', '大的'), ('long', '长的'),
                ('short', '短的；矮的'), ('tall', '高的'), ('giraffe', '长颈鹿'),
                ('deer', '鹿'),
            ],
        ],
        # 4.1
        # ('四年级上册词汇'),
        [
            [
                # ('人教版小学英语四年级上册单词表（三会）Unit 1'),
                ('window', '窗户'), ('have', '（我们）有'), ('board', '写字板'),
                ('new', '新的'), ('light', '灯，灯管'), ('go', '去'),
                ('picture', '画，图画'), ('where', '在哪里'), ('door', '门'),
                ('computer', '计算机'), ('floor', '地板'),
                ('teacher\'s desk', '讲台'),
                ('classroom', '教室'), ('wall', '墙'), ('many', '许多的'),
                ('fan', '扇子，电扇'), ('our', '我们的'),
                ('clean', '打扫，清洁，擦干净的'),
                ('classmate', '同学'), ('good idea', '好主意'),
                ('have a look', '瞧一瞧'), ('all right', '好吧，好的'),
                ('seat', '座位'), ('good job', '干的好'), ('near', '在……的旁边'),
                ('you', '您'), ('what', '什么'), ('see', '瞧'),
                ('in', '在……里面'),
                ('me', '我'), ('the', '这个，这里'), ('look at', '瞧……'),
                ('we', '我们'),
            ],
            [
                # ('人教版小学英语四年级上册单词表（三会）Unit 2'),
                ('Chinese book', '语文书'), ('pencil', '铅笔'),
                ('English book', '英语书'),
                ('twenty-one', '二十一'), ('math book', '数学书'),
                ('thirty-one', '三十一'), ('schoolbag', ''), ('书包'),
                ('forty-one', '[wʌn]'), ('四十一'), ('story-book', '故事书'),
                ('fifty', '五十'), ('notebook', '笔记本'), ('too many', '太多了'),
                ('colour', '颜色'), ('fat', '胖的'), ('heavy', '重的；沉重的'),
                ('may', '可以'), ('what\'s', '什么'), ('what is', '什么'),
                ('sure', '当然可以'), ('sorry', '对不起'),
                ('here you are', '给您'),
            ],
            [
                # ('人教版小学英语四年级上册单词表（三会）Unit 3'),
                ('long hair', '长头发'), ('short hair', '短头发'),
                ('thin', '瘦的'),
                ('strong', '健壮的'), ('quiet', '安静的'),
                ('friend', '朋友'), ('friends', '朋友(复数)'),
                ('Chinese', '中国的'),
                ('like', '喜欢'), ('his', '她的'), ('photo', '照片'),
                ('she has', '她有'), ('he has', '他有'), ('name', '名字'),
                ('he', '她'),
                ('teacher', '教师'), ('student', '学生'), ('music', '音乐'),
                ('science', '科学'), ('sports', '体育运动'),
                ('computer game', '电脑游戏'), ('painting', '绘画'),
                ('her', '她的'), ('you are', '你是'), ('she', '她'),
                ('right', '对的；正确的'), ('boy', '男孩'), ('girl', '女孩'),
                ('friend', '朋友'),
            ],
            [
                # ('人教版小学英语四年级上册单词表（三会）Unit 4'),
                ('study', '书房'), ('bathroom', '卫生间'), ('bedroom', '卧室'),
                ('living room', '客厅'), ('kitchen', '厨房'), ('it is', '它是'),
                ('hey', '嘿'), ('fish', '鱼'), ('is not', 'isn\'t', '不是'),
                ('home', '家'), ('room', '房间'), ('school', '学校'),
                ('classroom', '教室'), ('phone', '电话'), ('bed', '床'),
                ('sofa', '沙发'), ('shelf', '书架'), ('fridge', '冰箱'),
                ('table', '桌子'), ('they', '他们; 她们; 它们'),
                ('aren\'t', 'are not', '不是'),
                ('they\'re', 'they are', '他/她/它们是'),
                ('key', '钥匙'), ('open', '打开'), ('look', '瞧'),
                ('please', '请'),
                ('on', '在……上面'), ('no', '不；不就是'), ('window', '窗户'),
                ('desk', '课桌；书桌'), ('door', '门'), ('chair', '椅子'),
                ('bed', '床'),
            ],
            [
                # ('人教版小学英语四年级上册单词表（三会）Unit 5'),
                ('rice', '米饭'), ('fish', '鱼'), ('noodle', '面条'),
                ('noodles', '面条（复数）'), ('beef', '牛肉'),
                ('vegetable', '蔬菜'),
                ('soup', '汤'), ('have', '吃'), ('dinner', '晚餐；正餐'),
                ('wait', '等'), ('I\'d like', 'I would like', '我想要'),
                ('bread', '面包'), ('milk', '牛奶'), ('egg', '蛋'),
                ('water', '水'), ('hungry', '饥饿的'), ('for', '为；给'),
                ('thank you', '谢谢您'), ('knife', '刀'),
                ('chopsticks', '筷子（复数）'), ('spoon', '勺子'),
                ('plate', '盘子'), ('fork', '叉子'), ('help', '帮助；帮忙'),
                ('pass', '传递'), ('ready', '准备好了'), ('try', '常识；试一下'),
                ('help yourself', '别客气;随意;吃,不用害羞'), ('show', '展示'),
                ('yummy', '好吃的'), ('food', '食物'), ('use', '使用'),
                ('chicken', '鸡肉'),
            ],
            [
                # ('人教版小学英语四年级上册单词表（三会）Unit 6'),
                ('family', '家庭'), ('parents', '父母'), ('uncle', '叔叔；舅舅'),
                ('aunt', '姑姑；婶；姨'), ('baby', '婴儿'), ('people', '人'),
                ('member', '成员'), ('only', '只有；仅仅'), ('puppy', '小狗'),
                ('gee', '用以表示惊奇、赞赏'), ('come', '来'), ('who', '谁'),
                ('sister', '姐妹'), ('brother', '兄弟'),
                ('father', '父亲；爸爸'),
                ('baseball player', '棒球运动员'), ('driver', '司机'),
                ('doctor', '医生'), ('farmer', '农民'), ('nurse', '护士'),
                ('look', '瞧上去；瞧；瞧'), ('young', '年轻的'),
            ],
        ],
        # ('四年级下册词汇'),
        [
            [
                # ('人教版小学英语四年级下册单词表（三会）Unit 1'),
                ('computer', '计算机'), ('board', '写字板'), ('fan', '风扇'),
                ('light', '灯'), ('this', '这；这个'), ('is', '就是'),
                ('my', '我的'), ('that', '那；那个'), ('your', '您的'),
                ('teacher\'s desk', '讲台'), ('picture', '图画；照片'),
                ('wall', '墙壁'),
                ('floor', '地板'), ('yes', '就是；就是的'), ('it', '它'),
            ],
            [
                # ('人教版小学英语四年级下册单词表（三会）Unit 2'),
                ('class', '课程'), ('one', '一'),
                ('two', '二'), ('three', '三'), ('four', '四'),
                ('five', '五'), ('six', '六'), ('seven', '七'),
                ('eight', '八'),
                ('nine', '九'), ('ten', '十'), ('what', '什么'),
                ('time', '时间'),
                ('it\'s', 'it is', '它是'), ('o\'clock', '…点钟'),
                ('math', '数学'),
                ('Chinese', '语文'), ('English', '英语'), ('PE', '体育'),
                ('music', '音乐'), ('for', '为；给'),

            ],
            [
                # ('人教版小学英语四年级下册单词表（三会）Unit 3'),
                ('jacket', '夹克衫'), ('shirt', '衬衫'), ('skirt', '裙子'),
                ('dress', '连衣裙'), ('T-shirt', 'T恤衫'), ('red', '红色的'),
                ('blue', '蓝色的'), ('yellow', '黄色的'), ('green', '绿色的'),
                ('white', '白色的'), ('no', '不；不就是'), ('not', '不；不就是的'),
                ('colour', 'color', '颜色'),

            ],
            [
                # ('人教版小学英语四年级下册单词表（三会）Unit 4'),
                ('warm', '暖与的'), ('cold', '寒冷的'), ('cool', '凉爽的'),
                ('today', '今天'), ('jeans', '牛仔裤'), ('pants', '长裤'),
                ('socks', '袜子'), ('shoes', '鞋子'),
                ('let\'s', 'let us', '让我们;我们一起'),
                ('play', '玩;踢'), ('football', '足球'), ('snowy', '下雪的'),
                ('sunny', '晴朗的'),

            ],
            [
                # ('人教版小学英语四年级下册单词表（三会）Unit 5'),
                ('how much', '多少钱'), ('big', '大的'), ('small', '小的'),
                ('long', '长的'), ('short', '短的'), ('apple', '苹果'),
                ('banana', '香蕉'), ('pear', '梨'), ('orange', '橙子'),
                ('watermelon', '西瓜'), ('are', '就是'), ('they', '它她，她们'),
            ],
            [
                # ('人教版小学英语四年级下册单词表（三会）Unit 6'),
                ('horse', '马'), ('aren\'t', 'are not', '不是'), ('cat', '猫'),
                ('rabbit', '兔子'), ('pig', '猪'), ('duck', '鸭子'),
                ('dog', '狗'),
                ('eleven', '十一'), ('twelve', '十二'), ('thirteen', '十三'),
                ('fifteen', '十五'), ('twenty', '二十'), ('how many', '多少'),
                ('there', '那儿;那里'),
            ]
        ],
        # ('五年级上册词汇'),
        [
            [
                # ('人教版小学英语五年级上册单词表（三会）Unit 1'),
                ('young', '年轻的'), ('funny', '滑稽可笑的'), ('tall', '高的'),
                ('strong', '强壮的'), ('kind', '与蔼的;亲切的'),
                ('old', '年老的'), ('short', '矮的'), ('thin', '瘦的'),
                ('Mr', '先生'), ('like', '像……一样；喜欢'), ('strict', '严格的'),
                ('smart', '聪明的;巧妙的'), ('active', '积极的;活跃的'),
                ('quiet', '安静的;文静的'), ('very', '很;非常'),
                ('but', '但就是'),

            ],
            [
                # ('人教版小学英语五年级上册单词表（三会）Unit 2'),
                ('Mondy', '星期一'), ('Tuesday', '星期二'),
                ('Wednesday', '星期三'), ('Thursday', '星期四'),
                ('Friday', '星期五'), ('Saturday', '星期六'),
                ('Sunday', '星期天'), ('day', '天'), ('have', '有;吃'),
                ('on', '在……时候'), ('do homework', '做作业'),
                ('watch TV', '看电视'), ('read books', '读书'),
            ],
            [
                # ('人教版小学英语五年级上册单词表（三会）Unit 3'),
                ('eggplant', '茄子'), ('fish', '鱼'),
                ('green beans', '青豆'), ('tofu', '豆腐'),
                ('potato', '土豆'), ('tomato', '西红柿'), ('for', '为'),
                ('lunch', '中餐'), ('we', '我们'), ('tasty', '好吃的'),
                ('sweet', '甜的'), ('sour', '酸的'), ('fresh', '新鲜的'),
                ('salty', '咸的'), ('favourite', '最喜欢的'),
                ('they are', '他/她/它们是'), ('fruit', '水果'), ('grape', '葡萄'),
            ],
            [
                # ('人教版小学英语五年级上册单词表（三会）Unit 4'),
                ('cook the meals', '煮饭'), ('water the flowers', '浇花'),
                ('sweep the floor', '扫地'), ('clean the bedroom', '打扫卧室'),
                ('make the bed', '铺床'), ('set the table', '摆饭桌'),
                ('wash the clothes', '洗衣服'),
                ('do the dishes', '洗碗;洗餐具'),
                ('use a computer', '使用计算机'),
            ],
            [
                # ('人教版小学英语五年级上册单词表（三会）Unit 5'),
                ('curtain', '窗帘'), ('trash bin', '垃圾箱'), ('closet', '壁橱'),
                ('mirror', '镜子'), ('bed table', '床头柜'), ('bedroom', '卧室'),
                ('kitchen', '厨房'), ('bathroom', '卫生间'),
                ('living room', '客厅'), ('in', '在……里面'), ('on', '在……上面'),
                ('under', '在……下面'), ('near', '在……旁边'),
                ('behind', '在……后边'), ('clothes', '衣服'),
            ],
            [
                # ('人教版小学英语五年级上册单词表（三会）Unit 6'),
                ('river', '河流'), ('flower', '花'), ('grass', '草'),
                ('lake', '湖泊'), ('forest', '森林'), ('path', '路'),
                ('park', '公园'), ('picture', '照片'), ('house', '房子'),
                ('bridge', '桥'), ('tree', '树'), ('road', '公路'),
                ('building', '建筑物'), ('clean', '干净的'),
            ],
        ],
        # ('五年级下册词汇'),
        [
            [
                # ('人教版小学英语五年级下册单词表（三会）Unit 1'),
                ('eat breakfast', '吃早饭'), ('have English class', '上英语课'),
                ('play sports', '进行体育运动'), ('eat dinner', '吃晚饭'),
                ('when', '什么时候'), ('evening', '夜晚;晚上'),
                ('get up', '起床'),
                ('at', '在……点钟'), ('usually', '通常;一般'),
                ('noon', '中午'), ('climb mountains', 'climb mountain', '爬山'),
                ('go shopping', '购物;买东西'),
                ('play the piano', '弹钢琴'),
                ('visit grandparents', '探望祖父母'),
                ('go hiking', '去远足'), ('weekend', '周末'), ('often', '经常'),
                ('sometimes', '有时候'),

            ],
            [
                # ('人教版小学英语五年级下册单词表（三会）Unit 2'),
                ('spring', '春天'), ('summer', '夏天'), ('fall', '秋天'),
                ('winter', '冬天'), ('season', '季节'), ('which', '哪一个'),
                ('best', '最;极'), ('swim', '游泳'),
                ('fly kites', 'fly kite', '放风筝'), ('skate', '滑冰;滑冰鞋'),
                ('make a snowman', '堆雪人'), ('plant trees', '种树'),
                ('why', '为什么'), ('because', 'cause', '因为'),
                ('sleep', '睡觉'),
            ],
            [
                # ('人教版小学英语五年级下册单词表（三会）Unit 3'),
                ('Jan', 'January', '一月'), ('Feb', 'February', '二月'),
                ('Mar', 'March', '三月'), ('Apr', 'April', '四月'),
                ('May', '五月'), ('June', '六月'), ('July', '七月'),
                ('Aug', 'August', '八月'), ('Sept', 'September', '九月'),
                ('Oct', 'October', '十月'), ('Nov', 'November', '十一月'),
                ('Dec', 'December', '十二月'), ('birthday', '生日'),
                ('uncle', '叔叔;舅舅'), ('her', '她的'), ('date', '日期'),
            ],
            [
                # ('人教版小学英语五年级下册单词表（三会）Unit 4'),
                ('draw pictures', 'draw picture', '画画'),
                ('cook dinner', '做饭'), ('read a book', '看书'),
                ('answer the phone', '接电话'),
                ('listen to music', '听音乐'), ('clean the room', '打扫房间'),
                ('write a letter', '写信'), ('write an e-mail', '写电子邮件'),
                ('mom', '妈妈'), ('grandpa', '爷爷;外公'),
                ('study', '书房'),
            ],
            [
                # ('人教版小学英语五年级下册单词表（三会）Unit 5'),
                ('fly', '飞'), ('jump', '跳'), ('walk', '走'), ('run', '跑'),
                ('swim', '游泳'), ('kangaroo', '袋鼠'), ('sleep', '睡觉'),
                ('climb', '往上爬'), ('fight', '打架'), ('swing', '荡;荡秋千'),
                ('drink water', '喝水'),
            ],
            [
                # ('人教版小学英语五年级下册单词表（三会）Unit 6'),
                ('take pictures', '照相'),
                ('watch insects', 'watch insect', '观察昆虫'),
                ('pick up leave', 'pick up leaves', '采摘树叶'),
                ('do an experiment', '做实验'), ('catch butterfly', '捉蝴蝶'),
                ('honey', '蜂蜜'), ('count insects', '数昆虫'),
                ('collect leaves', '收集树叶'), ('write a report', '写报告'),
                ('play chess', '下棋'), ('have a picnic', '举行野餐'),
            ]
        ],
        [
            # ('六年级上册词汇'),
            [
                # ('人教版小学英语六年级上册单词表（三会）Unit 1'),
                ('by', '通过;乘坐'), ('foot', '脚'), ('bike', '自行车'),
                ('bus', '公共汽车'), ('train', '火车'), ('how', '怎样'),
                ('go to school', '上学'), ('traffic', '交通'),
                ('traffic light', '交通灯'), ('traffic rule', '交通规则'),
                ('stop', '停;停车站'), ('wait', '等待'), ('get to', '到达'),
            ],
            [
                # ('人教版小学英语六年级上册单词表（三会）Unit 2'),
                ('library', '图书馆'), ('post office', '邮局'),
                ('hospital', '医院'), ('cinema', '电影院'), ('bookstore', '书店'),
                ('where', '在哪里;到哪里'), ('please', '请'),
                ('next to', '与……相邻'), ('turn', '转弯'), ('right', '右边'),
                ('left', '左边'), ('straight', '成直线地'), ('then', '然后'),
            ],
            [
                # ('人教版小学英语六年级上册单词表（三会）Unit 3'),
                ('next week', '下周'), ('this morning', '今天上午'),
                ('this afternoon', '今天下午'), ('this evening', '今天晚上'),
                ('comic book', '漫画书'), ('post card', '明信片'),
                ('newspaper', '报纸'), ('buy', '购买'),
            ],
            [
                # ('人教版小学英语六年级上册单词表（三会）Unit 4'),
                ('hobby', '爱好'), ('ride a bike', 'riding a bike', '骑自行车'),
                ('dive', 'diving', '跳水'),
                ('play the violin', 'playing the violin', '拉小提琴'),
                ('make kites', 'making kites', '制作风筝'),
                ('collect stamps', 'collecting stamps', '收集邮票'),
                ('live', 'lives', '居住'), ('teach', 'teaches', '教'),
                ('go', 'goes', '去'), ('watch', 'watches', '瞧'),
                ('read', 'reads', '读'), ('doesn\'t', 'does not', '不做'),
            ],
            [
                # ('人教版小学英语六年级上册单词表（三会）Unit 5'),
                ('singer', '歌唱家;歌手'), ('writer', '作家'),
                ('actor', '男演员'), ('actress', '女演员'),
                ('artist', '画家'), ('TV reporter', '电视台记者'),
                ('engineer', '工程师'), ('accountant', '会计'),
                ('policeman', '男警察'), ('salesperson', '销售员'),
                ('cleaner', '清洁工'), ('where', '在哪里;到哪里'),
                ('work', '工作'),
            ],
            [
                # ('人教版小学英语六年级上册单词表（三会）Unit 6'),
                ('rain', '雨'), ('cloud', '云'), ('sun', '太阳'),
                ('stream', '河;溪'), ('come from', '来自;从……来'),
                ('seed', '种子'), ('soil', '土壤'), ('sprout', '苗;芽'),
                ('plant', '植物;种植'), ('should', '应该'), ('then', '然后'),
            ]
        ],
        [
            # ('六年级下册词汇'),
            [
                # ('人教版小学英语六年级下册单词表（三会）Unit 1'),
                ('taller', '更高的'), ('shorter', '更矮的'),
                ('stronger', '更强壮的'),
                ('older', '年龄更大的'), ('younger', '更年轻的'),
                ('bigger', '更大的'), ('heavier', '更重的'), ('longer', '更长的'),
                ('thinner', '更瘦的'), ('smaller', '体型更小的'),
            ],
            [
                # ('人教版小学英语六年级下册单词表（三会）Unit 2'),
                ('have a fever', '发烧'), ('have a sore throat', '喉咙疼'),
                ('have a cold', '感冒'), ('have a toothache', '牙疼'),
                ('have a headache', '头疼'), ('matter', '事情;麻烦'),
                ('sore', '疼的'), ('hurt', '疼痛'), ('nose', '鼻子'),
                ('tired', '疲劳的;累的'), ('excited', '兴奋的'),
                ('angry', '生气的'), ('happy', '高兴的'),
                ('bored', '无聊的，烦人的'),
                ('sad', '忧伤的，悲伤的'),
            ],
            [
                # ('人教版小学英语六年级下册单词表（三会）Unit 3'),
                ('watched', '瞧'), ('washed', '洗'), ('cleaned', '打扫'),
                ('played', '玩'), ('visited', '瞧望'), ('read', '读'),
                ('did', '进行,做'), ('last weekend', '上一个周末'),
                ('went', '去'), ('went to a park', '去公园'),
                ('went swimming', '去游泳'),
                ('went fishing', '去钓鱼'), ('went hiking', '去郊游'),
            ],
            [
                # ('人教版小学英语六年级下册单词表（三会）Unit 4'),
                ('learned Chinese', '学汉语,学语文'),
                ('sang and danced', '唱歌与跳舞'),
                ('ate good food', '吃好吃的食物'),
                ('took pictures', 'took picture', '照相'), ('climbed', '爬'),
                ('had buy presents', 'bought presents', '买礼物'),
                ('rowed a boat', '划船'), ('saw elephant', '看大象'),
                ('went skiing', '去滑雪'), ('went ice-skating', '去滑冰'),
                ('how', '怎么,如何'), ('got', '到达'),
                ('last', '上一个的，仅余的，留在最后的'),
            ]
        ]
    ]
